==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/membership-cache.h <==
// Cache of memberships.
//
// $Id: membership-cache.h,v 1.2 1994/07/31 23:34:19 inge Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef MEMBERSHIP_CACHE__H
#define MEMBERSHIP_CACHE__H

#include "kom-types.h"
#include "misc.h"
#include "membership.h"
#include "int.Membership.CHMap.h"
#include "int.get_membership_question_ptr.CHMap.h"


class Membership_cache {
  public:
    Membership_cache(Connection *c);
    Membership_cache(const Membership_cache&);
    Membership_cache& operator=(const Membership_cache&);
    ~Membership_cache();

    // Methods working on the entire cache:
    Connection  * connection() const;
    Bool          present(Pers_no pno, Conf_no cno) const;
    void          clear();

    // Methods working on individual conf-stats.
    Status        prefetch(Pers_no pno, Conf_no cno);
    Membership    get(Pers_no pno, Conf_no cno);
    void          remove(Pers_no pno, Conf_no cno);

  private:
    class Immap : private intMembershipCHMap {
      public:
	Bool present(int index) const;
	Membership & operator[](int index);
	Immap();
    };

    class Imreqmap : private intget_membership_question_ptrCHMap {
      public:
    	Bool present(int index);
    	void delete_entry(int index);
    	get_membership_question *& operator[](int index);
    	Imreqmap();
    };

    Connection* conn;
    Immap       statusmap;
    Imreqmap    pendingmap;
};

#endif

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/membership-cache.h <==
// Cache of memberships.
//
// $Id: membership-cache.h,v 1.4 1995/11/18 22:49:45 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_MEMBERSHIP_CACHE_H
#define KOMXX_MEMBERSHIP_CACHE_H

#include "kom-types.h"
#include "misc.h"
#include "membership.h"
#include "int.Membership.CHMap.h"
#include "int.get_membership_question_ptr.CHMap.h"


class Membership_cache {
  public:
    Membership_cache(Connection *c);
    Membership_cache(const Membership_cache&);
    Membership_cache& operator=(const Membership_cache&);
    ~Membership_cache();

    // Methods working on the entire cache:
    Connection  * connection() const;
    bool          present(Pers_no pno, Conf_no cno) const;
    void          clear();

    // Methods working on individual conf-stats.
    Status        prefetch(Pers_no pno, Conf_no cno);
    Membership    get(Pers_no pno, Conf_no cno);
    void          remove(Pers_no pno, Conf_no cno);

  private:
    class Immap : private intMembershipCHMap {
      public:
	bool present(int index) const;
	Membership & operator[](int index);
	Immap();
    };

    class Imreqmap : private intget_membership_question_ptrCHMap {
      public:
    	bool present(int index);
    	void delete_entry(int index);
    	get_membership_question *& operator[](int index);
    	Imreqmap();
    };

    Connection* conn;
    Immap       statusmap;
    Imreqmap    pendingmap;
};

#endif
